@@ -1,10 +1,10 @@
-use std::{collections::HashMap, fmt::Debug};
+use std::{collections::HashMap};
 
 use crate::Value;
 
 
 #[derive(Debug, PartialEq)]
-pub struct CastleResult<Ctx: Debug, E: Debug> {
+pub struct CastleResult<Ctx, E> {
     pub data: HashMap<Box<str>, Value<Ctx, E>>,
     pub errors: Vec<E>
 }
\ No newline at end of file
